@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: BSD-2-Clause
  *
- * Copyright (c) 2018-2023 Gavin D. Howard and contributors.
+ * Copyright (c) 2018-2024 Gavin D. Howard and contributors.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -493,7 +493,7 @@
 #define BC_VM_SAFE_RESULT(r) ((r)->t >= BC_RESULT_TEMP)
 
 /// The invalid locale catalog return value.
-#define BC_VM_INVALID_CATALOG ((nl_catd) -1)
+#define BC_VM_INVALID_CATALOG ((nl_catd) - 1)
 
 /**
  * Returns true if the *unsigned* multiplication overflows.
@@ -791,8 +791,9 @@ bc_vm_info(const char* const help);
  * The entrance point for bc/dc together.
  * @param argc  The count of arguments.
  * @param argv  The argument array.
+ * @return      A status.
  */
-void
+BcStatus
 bc_vm_boot(int argc, char* argv[]);
 
 /**
@@ -1045,8 +1046,9 @@ bc_vm_fatalError(BcErr e);
  * A function to call at exit.
  * @param status  The exit status.
  */
-int
-bc_vm_atexit(int status);
+BcStatus
+bc_vm_atexit(BcStatus status);
+
 #endif // BC_ENABLE_LIBRARY
 
 /// A reference to the copyright header.
