@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: BSD-2-Clause
  *
- * Copyright (c) 2018-2023 Gavin D. Howard and contributors.
+ * Copyright (c) 2018-2024 Gavin D. Howard and contributors.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -56,6 +56,7 @@
 int
 main(int argc, char* argv[])
 {
+	BcStatus s;
 	char* name;
 	size_t len = strlen(BC_EXECPREFIX);
 
@@ -100,18 +101,19 @@ main(int argc, char* argv[])
 	BC_SETJMP_LOCKED(vm, exit);
 
 #if !DC_ENABLED
-	bc_main(argc, argv);
+	s = bc_main(argc, argv);
 #elif !BC_ENABLED
-	dc_main(argc, argv);
+	s = dc_main(argc, argv);
 #else
 	// BC_IS_BC uses vm->name, which was set above. So we're good.
-	if (BC_IS_BC) bc_main(argc, argv);
-	else dc_main(argc, argv);
+	if (BC_IS_BC) s = bc_main(argc, argv);
+	else s = dc_main(argc, argv);
 #endif
 
+	vm->status = (int) s;
+
 exit:
 	BC_SIG_MAYLOCK;
 
-	// Ensure we exit appropriately.
-	return bc_vm_atexit((int) vm->status);
+	return vm->status == BC_STATUS_QUIT ? BC_STATUS_SUCCESS : vm->status;
 }
