@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: BSD-2-Clause
  *
- * Copyright (c) 2018-2023 Gavin D. Howard and contributors.
+ * Copyright (c) 2018-2024 Gavin D. Howard and contributors.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -358,6 +358,7 @@ bc_vm_handleError(BcErr e, size_t line, ...)
 #endif // BC_DEBUG
 {
 	BcStatus s;
+	BcStatus fout_s;
 	va_list args;
 	uchar id = bc_err_ids[e];
 	const char* err_type = vm->err_ids[id];
@@ -383,14 +384,9 @@ bc_vm_handleError(BcErr e, size_t line, ...)
 	BC_SIG_TRYLOCK(lock);
 
 	// Make sure all of stdout is written first.
-	s = bc_file_flushErr(&vm->fout, bc_flush_err);
+	fout_s = bc_file_flushErr(&vm->fout, bc_flush_err);
 
-	// Just jump out if the flush failed; there's nothing we can do.
-	if (BC_ERR(s == BC_STATUS_ERROR_FATAL))
-	{
-		vm->status = (sig_atomic_t) s;
-		BC_JMP;
-	}
+	// XXX: Keep the status for later.
 
 	// Print the error message.
 	va_start(args, line);
@@ -429,18 +425,40 @@ bc_vm_handleError(BcErr e, size_t line, ...)
 
 	bc_file_puts(&vm->ferr, bc_flush_none, "\n");
 
+	// If flushing to stdout failed, try to print *that* error, as long as that
+	// was not the error already.
+	if (fout_s == BC_STATUS_ERROR_FATAL && e != BC_ERR_FATAL_IO_ERR)
+	{
+		bc_file_putchar(&vm->ferr, bc_flush_none, '\n');
+		bc_file_puts(&vm->ferr, bc_flush_none,
+		             vm->err_ids[bc_err_ids[BC_ERR_FATAL_IO_ERR]]);
+		bc_file_putchar(&vm->ferr, bc_flush_none, ' ');
+		bc_file_puts(&vm->ferr, bc_flush_none,
+		             vm->err_msgs[BC_ERR_FATAL_IO_ERR]);
+	}
+
 	s = bc_file_flushErr(&vm->ferr, bc_flush_err);
 
 #if !BC_ENABLE_MEMCHECK
+
 	// Because this function is called by a BC_NORETURN function when fatal
 	// errors happen, we need to make sure to exit on fatal errors. This will
 	// be faster anyway. This function *cannot jump when a fatal error occurs!*
-	if (BC_ERR(id == BC_ERR_IDX_FATAL || s == BC_STATUS_ERROR_FATAL))
+	if (BC_ERR(id == BC_ERR_IDX_FATAL || fout_s == BC_STATUS_ERROR_FATAL ||
+	           s == BC_STATUS_ERROR_FATAL))
 	{
-		exit(bc_vm_atexit((int) BC_STATUS_ERROR_FATAL));
+		exit((int) BC_STATUS_ERROR_FATAL);
 	}
+
 #else // !BC_ENABLE_MEMCHECK
-	if (BC_ERR(s == BC_STATUS_ERROR_FATAL)) vm->status = (sig_atomic_t) s;
+	if (BC_ERR(fout_s == BC_STATUS_ERROR_FATAL))
+	{
+		vm->status = (sig_atomic_t) fout_s;
+	}
+	else if (BC_ERR(s == BC_STATUS_ERROR_FATAL))
+	{
+		vm->status = (sig_atomic_t) s;
+	}
 	else
 #endif // !BC_ENABLE_MEMCHECK
 	{
@@ -1528,7 +1546,7 @@ bc_vm_exec(void)
 	if (BC_VM_RUN_STDIN(has_file)) bc_vm_stdin();
 }
 
-void
+BcStatus
 bc_vm_boot(int argc, char* argv[])
 {
 	int ttyin, ttyout, ttyerr;
@@ -1572,8 +1590,8 @@ bc_vm_boot(int argc, char* argv[])
 #if BC_ENABLE_LINE_LIB
 
 	// Initialize the output file buffers.
-	bc_file_init(&vm->ferr, stderr);
-	bc_file_init(&vm->fout, stdout);
+	bc_file_init(&vm->ferr, stderr, true);
+	bc_file_init(&vm->fout, stdout, false);
 
 	// Set the input buffer.
 	vm->buf = output_bufs;
@@ -1583,8 +1601,9 @@ bc_vm_boot(int argc, char* argv[])
 	// Initialize the output file buffers. They each take portions of the global
 	// buffer. stdout gets more because it will probably have more data.
 	bc_file_init(&vm->ferr, STDERR_FILENO, output_bufs + BC_VM_STDOUT_BUF_SIZE,
-	             BC_VM_STDERR_BUF_SIZE);
-	bc_file_init(&vm->fout, STDOUT_FILENO, output_bufs, BC_VM_STDOUT_BUF_SIZE);
+	             BC_VM_STDERR_BUF_SIZE, true);
+	bc_file_init(&vm->fout, STDOUT_FILENO, output_bufs, BC_VM_STDOUT_BUF_SIZE,
+	             false);
 
 	// Set the input buffer to the rest of the global buffer.
 	vm->buf = output_bufs + BC_VM_STDOUT_BUF_SIZE + BC_VM_STDERR_BUF_SIZE;
@@ -1716,6 +1735,11 @@ bc_vm_boot(int argc, char* argv[])
 
 	// Start executing.
 	bc_vm_exec();
+
+	BC_SIG_LOCK;
+
+	// Exit.
+	return bc_vm_atexit((BcStatus) vm->status);
 }
 #endif // !BC_ENABLE_LIBRARY
 
@@ -1786,11 +1810,11 @@ bc_vm_atexit(void)
 #endif // BC_DEBUG
 }
 #else // BC_ENABLE_LIBRARY
-int
-bc_vm_atexit(int status)
+BcStatus
+bc_vm_atexit(BcStatus status)
 {
 	// Set the status correctly.
-	int s = BC_STATUS_IS_ERROR(status) ? status : BC_STATUS_SUCCESS;
+	BcStatus s = BC_STATUS_IS_ERROR(status) ? status : BC_STATUS_SUCCESS;
 
 	bc_vm_shutdown();
 
